==> odoo12_addon_purchase_request_operating_unit-12.0.1.0.0.99.dev5-py3-none-any.whl: odoo/addons/purchase_request_operating_unit/wizard/purchase_request_line_make_purchase_order.py <==
# Copyright 2016-19 Eficent Business and IT Consulting Services S.L.
#   (http://www.eficent.com)
# Copyright 2016-19 Serpent Consulting Services Pvt. Ltd.
#   (<http://www.serpentcs.com>)
# License LGPL-3.0 or later (https://www.gnu.org/licenses/lgpl.html).

from odoo import api, fields, models, _
from odoo.exceptions import ValidationError


class PurchaseRequestLineMakePurchaseOrder(models.TransientModel):
    _inherit = "purchase.request.line.make.purchase.order"

    operating_unit_id = fields.Many2one(
        'operating.unit',
        string='Operating Unit',
        readonly=True,
    )

    @api.model
    def default_get(self, fields):
        res = super(PurchaseRequestLineMakePurchaseOrder, self).\
            default_get(fields)
        request_line_obj = self.env['purchase.request.line']
        request_line_ids = self._context.get('active_ids', [])
        operating_unit_id = False
        for line in request_line_obj.browse(request_line_ids):
            line_operating_unit_id = line.request_id.operating_unit_id \
                and line.request_id.operating_unit_id.id or False
            if operating_unit_id\
                    and line_operating_unit_id != operating_unit_id:
                raise ValidationError(_('Could not process !'
                                        'You have to select lines'
                                        'from the same operating unit.'))
            else:
                operating_unit_id = line_operating_unit_id
        res['operating_unit_id'] = operating_unit_id
        return res

    @api.model
    def _prepare_purchase_order(self, picking_type, location,
                                company_id, origin):
        data = super(PurchaseRequestLineMakePurchaseOrder, self).\
            _prepare_purchase_order(picking_type, location, company_id, origin)
        if self.operating_unit_id:
            data['requesting_operating_unit_id'] = \
                self.operating_unit_id.id
            data['operating_unit_id'] = \
                self.operating_unit_id.id
        return data

==> odoo12_addon_purchase_request_operating_unit-12.0.1.0.1.99.dev1-py3-none-any.whl: odoo/addons/purchase_request_operating_unit/wizard/purchase_request_line_make_purchase_order.py <==
# Copyright 2016-19 Eficent Business and IT Consulting Services S.L.
#   (http://www.eficent.com)
# Copyright 2016-19 Serpent Consulting Services Pvt. Ltd.
#   (<http://www.serpentcs.com>)
# License LGPL-3.0 or later (https://www.gnu.org/licenses/lgpl.html).

from odoo import api, fields, models, _
from odoo.exceptions import ValidationError


class PurchaseRequestLineMakePurchaseOrder(models.TransientModel):
    _inherit = "purchase.request.line.make.purchase.order"

    operating_unit_id = fields.Many2one(
        'operating.unit',
        string='Operating Unit',
        readonly=True,
    )

    @api.model
    def default_get(self, fields):
        res = super(PurchaseRequestLineMakePurchaseOrder, self).\
            default_get(fields)
        request_line_obj = self.env['purchase.request.line']
        active_model = self.env.context.get('active_model', False)
        request_line_ids = []
        if active_model == 'purchase.request.line':
            request_line_ids += self.env.context.get('active_ids', [])
        elif active_model == 'purchase.request':
            request_ids = self.env.context.get('active_ids', False)
            request_line_ids += self.env[active_model].browse(
                request_ids).mapped('line_ids.id')
        if not request_line_ids:
            return res
        operating_unit_id = False
        for line in request_line_obj.browse(request_line_ids):
            line_operating_unit_id = line.request_id.operating_unit_id \
                and line.request_id.operating_unit_id.id or False
            if operating_unit_id\
                    and line_operating_unit_id != operating_unit_id:
                raise ValidationError(_('Could not process !'
                                        'You have to select lines'
                                        'from the same operating unit.'))
            else:
                operating_unit_id = line_operating_unit_id
        res['operating_unit_id'] = operating_unit_id
        return res

    @api.model
    def _prepare_purchase_order(self, picking_type, location,
                                company_id, origin):
        data = super(PurchaseRequestLineMakePurchaseOrder, self).\
            _prepare_purchase_order(picking_type, location, company_id, origin)
        if self.operating_unit_id:
            data['requesting_operating_unit_id'] = \
                self.operating_unit_id.id
            data['operating_unit_id'] = \
                self.operating_unit_id.id
        return data
